Introduction
=============

This manual includes details of how to use specific aspects of CastleCMS.

It is not a user guide. Instead, see the `CastleCMS training guide <https://help.castlecms.io/file-repository/castlecms-2-1-training-guide-20181106.pdf/view>`_

